// Create a Crab source model, print it to screen and save it in XML format
#include <iostream>
#include <GammaLib.hpp>

int main(void) {
  // Create the spatial part of the Crab source model
  double ra = 83.6331, dec = 22.0145;
  GSkyDir direction;
  direction.radec_deg(ra, dec);
  GModelSpatialPointSource spatial_model(direction);

  // Create the spectral part of the Crab source model
  // HEGRA publication : 2004ApJ...614..897A
  double norm = 2.83e-11, index = -2.62;
  GEnergy pivot_energy(1, "TeV");
  GModelSpectralPlaw spectral_model(norm, index, pivot_energy);

  // Create complete model and print it to the console
  GModelSky model(spatial_model, spectral_model);
  std::cout << model << std::endl;

  // To store the model in an XML file we need to put it in a models container
  GModels models;
  models.append(model);
  models.save("crab.xml");
  return 0;
}
