"""Create a Crab source model, print it to screen and save it in XML format"""

# Import the gammalib Python package 
import gammalib

# Create the spatial part of the Crab source model
ra, dec = 83.6331, 22.0145
direction = gammalib.GSkyDir()
direction.radec_deg(ra, dec)
spatial_model = gammalib.GModelSpatialPointSource(direction)

# Create the spectral part of the Crab source model
# HEGRA publication : 2004ApJ...614..897A
norm, index = 2.83e-11, -2.62
pivot_energy = gammalib.GEnergy(1, 'TeV')
spectral_model = gammalib.GModelSpectralPlaw(norm, index, pivot_energy)

# Create complete model and print it to the console
model = gammalib.GModelSky(spatial_model, spectral_model)
print(model)

# To store the model in an XML file we need to put it in a models container
models = gammalib.GModels()
models.append(model)
models.save('crab.xml')
